aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorChristian Weiske <cweiske@cweiske.de>2010-10-09 13:09:46 +0200
committerChristian Weiske <cweiske@cweiske.de>2010-10-09 13:09:46 +0200
commitefdcf11bb08e424cfbe140e167d8ece398ab74fa (patch)
tree892e36180b4bfb808908c0d7fdc8b3ded5ae0702 /src
parentb4f9d3b12644b5b5abd0b7da8e8c37d2659a2b4b (diff)
downloadsemanticscuttle-efdcf11bb08e424cfbe140e167d8ece398ab74fa.tar.gz
semanticscuttle-efdcf11bb08e424cfbe140e167d8ece398ab74fa.tar.bz2
activate strict xhtml mode only on debug mode
Diffstat (limited to 'src')
-rw-r--r--src/SemanticScuttle/header.php13
1 files changed, 9 insertions, 4 deletions
diff --git a/src/SemanticScuttle/header.php b/src/SemanticScuttle/header.php
index 3caeb35..dc25581 100644
--- a/src/SemanticScuttle/header.php
+++ b/src/SemanticScuttle/header.php
@@ -120,10 +120,15 @@ $tplVars['userservice'] = $userservice;
if (!defined('UNIT_TEST_MODE')) {
//API files define that, so we need a way to support both of them
if (!isset($httpContentType)) {
- //$httpContentType = 'text/html';
- //using that mime type makes all javascript nice in Chromium
- // it also serves as test base if the pages really validate
- $httpContentType = 'application/xhtml+xml';
+ if (DEBUG_MODE) {
+ //using that mime type makes all javascript nice in Chromium
+ // it also serves as test base if the pages really validate
+ $httpContentType = 'application/xhtml+xml';
+ } else {
+ //until we are sure that all pages validate, we
+ // keep the non-strict mode on for normal installations
+ $httpContentType = 'text/html';
+ }
}
if ($httpContentType !== false) {
header('Content-Type: ' . $httpContentType . '; charset=utf-8');